# Generated by roxygen2: do not edit by hand

S3method(format,PMMdispatch)
S3method(logLik,PMM2fit)
S3method(logLik,PMM3fit)
S3method(logLik,TS2fit)
S3method(logLik,TS3fit)
S3method(print,PMMdispatch)
S3method(summary,PMMdispatch)
export(ar_pmm2)
export(ar_pmm3)
export(arima_pmm2)
export(arima_pmm3)
export(arma_pmm2)
export(arma_pmm3)
export(compare_ar_methods)
export(compare_arima_methods)
export(compare_arma_methods)
export(compare_ma_methods)
export(compare_sar_methods)
export(compare_ts_methods)
export(compare_with_ols)
export(compute_moments)
export(compute_moments_pmm3)
export(create_sar_matrix)
export(create_sarma_matrix)
export(lm_pmm2)
export(lm_pmm3)
export(ma_pmm2)
export(ma_pmm3)
export(plot_pmm2_bootstrap)
export(pmm2_inference)
export(pmm2_monte_carlo_compare)
export(pmm2_nonlinear_iterative)
export(pmm2_nonlinear_onestep)
export(pmm2_variance_factor)
export(pmm2_variance_matrices)
export(pmm3_variance_factor)
export(pmm3_variance_matrices)
export(pmm_ar)
export(pmm_arima)
export(pmm_arma)
export(pmm_dispatch)
export(pmm_gamma6)
export(pmm_kurtosis)
export(pmm_lm)
export(pmm_ma)
export(pmm_sarima)
export(pmm_skewness)
export(sar_pmm2)
export(sarima_pmm2)
export(sarma_pmm2)
export(sma_pmm2)
export(test_symmetry)
export(ts_pmm2)
export(ts_pmm2_inference)
export(ts_pmm3)
exportClasses(ARIMAPMM2)
exportClasses(ARIMAPMM3)
exportClasses(ARMAPMM2)
exportClasses(ARMAPMM3)
exportClasses(ARPMM2)
exportClasses(ARPMM3)
exportClasses(BasePMM2)
exportClasses(BasePMM3)
exportClasses(MAPMM2)
exportClasses(MAPMM3)
exportClasses(PMM2fit)
exportClasses(PMM3fit)
exportClasses(PMMfit)
exportClasses(PMMtsfit)
exportClasses(SARIMAPMM2)
exportClasses(SARMAPMM2)
exportClasses(SARPMM2)
exportClasses(SMAPMM2)
exportClasses(TS2fit)
exportClasses(TS3fit)
exportMethods(coef)
exportMethods(confint)
exportMethods(fitted)
exportMethods(nobs)
exportMethods(plot)
exportMethods(predict)
exportMethods(residuals)
exportMethods(show)
exportMethods(summary)
exportMethods(vcov)
importFrom(graphics,abline)
importFrom(graphics,hist)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,show)
importFrom(methods,slotNames)
importFrom(stats,acf)
importFrom(stats,aggregate)
importFrom(stats,arima)
importFrom(stats,arima.sim)
importFrom(stats,as.formula)
importFrom(stats,confint)
importFrom(stats,cov)
importFrom(stats,diffinv)
importFrom(stats,dnorm)
importFrom(stats,lm)
importFrom(stats,lm.fit)
importFrom(stats,logLik)
importFrom(stats,lowess)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,na.fail)
importFrom(stats,na.pass)
importFrom(stats,nobs)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(stats,qqline)
importFrom(stats,qqnorm)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,vcov)
importFrom(utils,head)
importFrom(utils,tail)
