% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pmm2_classes.R
\docType{class}
\name{ARMAPMM2-class}
\alias{ARMAPMM2-class}
\title{S4 class for storing PMM2 ARMA model results}
\description{
S4 class for storing PMM2 ARMA model results
}
