% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{DCOILWTICO}
\alias{DCOILWTICO}
\title{WTI Crude Oil Prices}
\format{
A data frame with observations for each trading day:
\describe{
\item{observation_date}{Date of observation in YYYY-MM-DD format}
\item{DCOILWTICO}{Crude Oil Price: West Texas Intermediate (WTI) in USD per barrel}
}
}
\source{
Federal Reserve Economic Data (FRED), Federal Reserve Bank of St. Louis
\url{https://fred.stlouisfed.org/series/DCOILWTICO}
}
\usage{
DCOILWTICO
}
\description{
Daily spot prices for West Texas Intermediate (WTI) crude oil
in U.S. dollars per barrel.
}
\examples{
data(DCOILWTICO)
head(DCOILWTICO)
summary(DCOILWTICO$DCOILWTICO)
}
\keyword{datasets}
