% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pmm3_utils.R
\name{pmm_gamma6}
\alias{pmm_gamma6}
\title{Compute sixth-order cumulant coefficient gamma6}
\usage{
pmm_gamma6(x)
}
\arguments{
\item{x}{numeric vector}
}
\value{
Numeric scalar: the sixth-order cumulant coefficient
}
\description{
Calculates \eqn{\gamma_6 = m_6/m_2^3 - 15 m_4/m_2^2 + 30} from a numeric
vector. For a Gaussian distribution gamma6 equals zero.
}
