% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pmm3_main.R
\name{vcov,PMM3fit-method}
\alias{vcov,PMM3fit-method}
\title{Variance-covariance matrix for PMM3fit objects}
\usage{
\S4method{vcov}{PMM3fit}(object, ...)
}
\arguments{
\item{object}{PMM3fit object}

\item{...}{Additional arguments (not used)}
}
\value{
Numeric matrix of the same dimension as the number of coefficients
}
\description{
Returns the asymptotic covariance matrix
\eqn{V_{\mathrm{PMM3}} = g_3\,\sigma^2 (X^\top X)^{-1}} where
\eqn{g_3 = 1 - \gamma_4^{2} / (6 + 9\gamma_4 + \gamma_6)}
is the PMM3 variance reduction factor (Kunchenko's polynomial
maximization method, s = 3 specialised to symmetric platykurtic
errors; see \code{\link{pmm3_variance_matrices}}). Under Gaussian
errors \eqn{g_3 = 1} and the result equals the OLS covariance.
}
