% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pmm2_classes.R
\docType{class}
\name{SARMAPMM2-class}
\alias{SARMAPMM2-class}
\title{S4 class for Seasonal ARMA model results with PMM2}
\description{
This class stores the results of fitting a Seasonal Autoregressive Moving Average
(SARMA) model using the PMM2 method. It combines both seasonal AR and seasonal MA
components.
}
\details{
The SARMAPMM2 class represents fitted SARMA models combining:
\itemize{
\item AR(p): \eqn{\phi_1 y_{t-1} + \dots + \phi_p y_{t-p}}
\item Seasonal AR component: \eqn{\Phi_1 y_{t-s} + \dots + \Phi_P y_{t-Ps}}
\item MA(q): \eqn{\theta_1 \epsilon_{t-1} + \dots + \theta_q \epsilon_{t-q}}
\item Seasonal MA component: \eqn{\Theta_1 \epsilon_{t-s} + \dots + \Theta_Q \epsilon_{t-Qs}}
}
}
\section{Slots}{

\describe{
\item{\code{coefficients}}{Numeric vector of estimated parameters (SAR and SMA coefficients)}

\item{\code{residuals}}{Numeric vector of residuals/innovations}

\item{\code{m2}}{Second central moment of residuals}

\item{\code{m3}}{Third central moment of residuals}

\item{\code{m4}}{Fourth central moment of residuals}

\item{\code{convergence}}{Logical, whether PMM2 algorithm converged}

\item{\code{iterations}}{Integer, number of iterations performed}

\item{\code{call}}{Original function call}

\item{\code{model_type}}{Character, model type identifier ("sarma")}

\item{\code{intercept}}{Numeric, intercept/mean term}

\item{\code{original_series}}{Numeric vector, original time series data}

\item{\code{order}}{List with model specification: list(ar, sar, ma, sma, period)
\itemize{
\item ar: Non-seasonal AR order (p)
\item sar: Seasonal AR order (P)
\item ma: Non-seasonal MA order (q)
\item sma: Seasonal MA order (Q)
\item period: Seasonal period (s)
}}
}}

\seealso{
\code{\link{sarma_pmm2}} for fitting SARMA models
}
