% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pmm2_ts_methods.R
\name{compare_sar_methods}
\alias{compare_sar_methods}
\title{Compare SAR model estimation methods}
\usage{
compare_sar_methods(
  x,
  order = c(1, 1),
  period = 12,
  methods = c("ols", "pmm2", "css"),
  verbose = TRUE
)
}
\arguments{
\item{x}{Time series data}

\item{order}{Model order c(p, P) for SAR specification}

\item{period}{Seasonal period}

\item{methods}{Character vector of methods to compare (default: c("ols", "pmm2", "css"))}

\item{verbose}{Logical: print results to console (default TRUE)}
}
\value{
Data frame with comparison results (invisibly)
}
\description{
Compares different estimation methods (OLS, PMM2, CSS, ML) for SAR models
on the same data.
}
\examples{
\donttest{
set.seed(42)
y <- arima.sim(n = 120,
  model = list(order = c(1, 0, 0), ar = 0.7,
    seasonal = list(order = c(1, 0, 0), ar = 0.5, period = 12)))
compare_sar_methods(y, order = c(1, 1), period = 12)
}
}
