% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pmm2_classes.R
\docType{class}
\name{SARIMAPMM2-class}
\alias{SARIMAPMM2-class}
\title{S4 class for Seasonal ARIMA model results with PMM2}
\description{
This class stores the results of fitting a Seasonal Autoregressive Integrated
Moving Average (SARIMA) model using the PMM2 method. It extends SARMA with
differencing operators.
}
\details{
The SARIMAPMM2 class represents fitted SARIMA(p,d,q) x (P,D,Q)_s models:
\deqn{(1 - \phi_1 B - \dots - \phi_p B^p)(1 - \Phi_1 B^s - \dots - \Phi_P B^{Ps})(1 - B)^d (1 - B^s)^D y_t = (1 + \theta_1 B + \dots + \theta_q B^q)(1 + \Theta_1 B^s + \dots + \Theta_Q B^{Qs}) \epsilon_t.}

Where B is the backshift operator.
}
\section{Slots}{

\describe{
\item{\code{coefficients}}{Numeric vector of estimated parameters}

\item{\code{residuals}}{Numeric vector of residuals/innovations}

\item{\code{m2}}{Second central moment of residuals}

\item{\code{m3}}{Third central moment of residuals}

\item{\code{m4}}{Fourth central moment of residuals}

\item{\code{convergence}}{Logical, whether PMM2 algorithm converged}

\item{\code{iterations}}{Integer, number of iterations performed}

\item{\code{call}}{Original function call}

\item{\code{model_type}}{Character, model type identifier ("sarima")}

\item{\code{intercept}}{Numeric, intercept/mean term}

\item{\code{original_series}}{Numeric vector, original time series data}

\item{\code{order}}{List with model specification: list(ar, sar, ma, sma, d, D, period)
\itemize{
\item ar: Non-seasonal AR order (p)
\item sar: Seasonal AR order (P)
\item ma: Non-seasonal MA order (q)
\item sma: Seasonal MA order (Q)
\item d: Non-seasonal differencing order
\item D: Seasonal differencing order
\item period: Seasonal period (s)
}}
}}

\seealso{
\code{\link{sarima_pmm2}} for fitting SARIMA models
}
