% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pmm3_ts_classes.R
\docType{class}
\name{ARMAPMM3-class}
\alias{ARMAPMM3-class}
\title{S4 class for PMM3 ARMA model results}
\description{
S4 class for PMM3 ARMA model results
}
