% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pmm2_unified.R
\name{solve_pmm2_step}
\alias{solve_pmm2_step}
\title{PMM2 step solver}
\usage{
solve_pmm2_step(residuals, J, pmm_stats)
}
\arguments{
\item{residuals}{Current residuals}

\item{J}{Jacobian matrix (n x p), where J_ij = d(y_hat_i)/d(theta_j).
We assume the standard regression definition: y = f(theta) + e,
so e = y - f(theta) and d(e)/d(theta) = -d(f)/d(theta).
We expect J = d(f)/d(theta) (gradient of the regression function).}

\item{pmm_stats}{Statistics from compute_pmm2_components}
}
\value{
Update vector delta
}
\description{
Solves the linearized system to find the parameter update.
Based on the Taylor expansion: e(theta) ~ e(theta_k) - J * delta
}
